import { TextDocument, WorkspaceFolder } from "vscode-languageserver";
import { IConnectionLogger, InkConfigurationSettings, InkError, InkWorkspace, PartialInkConfigurationSettings } from "./types";
/**
 * The global settings, used when the `workspace/configuration` request is not supported
 * by the client.
 */
export declare const DEFAULT_SETTINGS: InkConfigurationSettings;
/******************************************************************************/
/**
 * Prepare the workspace for compilation. Create a temporary directory and
 * copies all of the project ink files into it, while preserving the subdirectory
 * hierarchy. The resulting directory should be kept safely for the remaining
 * of the session.
 *
 * @param workspace the workspace containing all the ink files.
 * @param connection the client connection.
 * @returns the temporary directory containing copies of the workspace's ink files.
 */
export declare function prepareTempDirectoryForCompilation(workspaceFolder: WorkspaceFolder, logger: IConnectionLogger, callback: (tempDirectory: string | undefined) => void): void;
/**
 * Replace the original ink file found in `workspace.temporaryCompilationDirectory`,
 * with the update content of `document`.
 *
 * @param document document holding the new content.
 * @param workspace the workspace to which the document belongs.
 * @param callback called once the file has been updated.
 */
export declare function updateFile(document: TextDocument, workspace: InkWorkspace, logger: IConnectionLogger, callback: (error: Error) => void): void;
/**
 * Compile the project and report any errors through `completion`.
 *
 * @param settings the configuration settings to use.
 * @param inkWorkspace the workspace to compile.
 * @param connection the client connection.
 * @param completion the callback to call upon completion.
 */
export declare function compileProject(settings: PartialInkConfigurationSettings, inkWorkspace: InkWorkspace, logger: IConnectionLogger, completion: (inkWorkspace: InkWorkspace, outputStoryPath: string, errors: InkError[]) => void): void;
