import { DiagnosticSeverity } from "vscode-languageserver";
import { InkConfigurationSettings, InkErrorType, PartialInkConfigurationSettings, Platform } from "./types";
/**
 * Returns `true` if `filePath` point to a file that is a child of
 * the directory `dirPath` points to.
 *
 * @param filePath path to he file.
 * @param dirPath path to the directory.
 */
export declare function isFilePathChildOfDirPath(filePath: string, dirPath: string): boolean;
/**
 * Transform an InkErrorType into its equivalent DiagnosticSeverity.
 * @param type the InkErrorType to transform.
 */
export declare function getDiagnosticSeverityFromInkErrorType(type: InkErrorType): DiagnosticSeverity;
export declare function determinePlatform(): Platform;
/**
 * Returns true if the current setup requires Inklecate to be run through mono.
 */
export declare function isRunThroughMono(): boolean;
/**
 * Returns the default path to inklecate depending on the given Platform.
 *
 * @param platform the Platform for which return the default inklecate path.
 */
export declare function defaultInklecatePath(platform: Platform): string;
/**
 * Merge the given settings with the default one,
 * replacing any empty or undefined values.
 *
 * @param settings the provided configuration settings.
 * @param defaultSettings the default settings to use if values are empty or undefined.
 */
export declare function mergeSettings(settings: PartialInkConfigurationSettings, defaultSettings: InkConfigurationSettings): InkConfigurationSettings;
/**
 * Returns given string with escaped characters, for use as a regular expression pattern.
 *
 * @param source the string to escape
 */
export declare function escapeForRegExp(source: string): string;
